# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/processing/processing.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/processing/processing.proto',
  package='yamcs.protobuf.processing',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\017ProcessingProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/processing/processing.proto\x12\x19yamcs.protobuf.processing\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/commanding/commanding.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"+\n\x1aListProcessorTypesResponse\x12\r\n\x05types\x18\x01 \x03(\t\")\n\x15ListProcessorsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"[\n\x16ListProcessorsResponse\x12\x41\n\nprocessors\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\":\n\x13GetProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"=\n\x16\x44\x65leteProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"|\n\x16\x43reateProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x63lientId\x18\x03 \x03(\x05\x12\x12\n\npersistent\x18\x04 \x01(\x08\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x06 \x01(\t\"\x83\x01\n\x14\x45\x64itProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12(\n\x04seek\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05speed\x18\x05 \x01(\t\"q\n\x18GetParameterValueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tfromCache\x18\x04 \x01(\x08\x12\x0f\n\x07timeout\x18\x05 \x01(\x04\"s\n\x18SetParameterValueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12$\n\x05value\x18\x04 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"\x94\x01\n\x1e\x42\x61tchGetParameterValuesRequest\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x11\n\tprocessor\x18\x05 \x01(\t\x12)\n\x02id\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x11\n\tfromCache\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x04\"W\n\x1f\x42\x61tchGetParameterValuesResponse\x12\x34\n\x05value\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\"\x97\x02\n\x1e\x42\x61tchSetParameterValuesRequest\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x11\n\tprocessor\x18\x03 \x01(\t\x12\x63\n\x07request\x18\x01 \x03(\x0b\x32R.yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest\x1ak\n\x18SetParameterValueRequest\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"\xce\x02\n\x13IssueCommandRequest\x12\x10\n\x08instance\x18\x06 \x01(\t\x12\x11\n\tprocessor\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12M\n\nassignment\x18\x01 \x03(\x0b\x32\x39.yamcs.protobuf.processing.IssueCommandRequest.Assignment\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x03 \x01(\x05\x12\x0e\n\x06\x64ryRun\x18\x04 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12\x41\n\x0e\x63ommandOptions\x18\n \x01(\x0b\x32).yamcs.protobuf.commanding.CommandOptions\x1a)\n\nAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xe1\x01\n\x14IssueCommandResponse\x12\n\n\x02id\x18\x05 \x01(\t\x12\x32\n\x0egenerationTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x08 \x01(\x05\x12\x13\n\x0b\x63ommandName\x18\t \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0b\n\x03hex\x18\x03 \x01(\t\x12\x0e\n\x06\x62inary\x18\x04 \x01(\x0c\x12\x10\n\x08username\x18\x0b \x01(\t\x12\r\n\x05queue\x18\n \x01(\t\"\xa4\x01\n\x1bUpdateCommandHistoryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x46\n\nattributes\x18\x05 \x03(\x0b\x32\x32.yamcs.protobuf.commanding.CommandHistoryAttribute2\xe3\x0f\n\rProcessingApi\x12\x7f\n\x12ListProcessorTypes\x12\x16.google.protobuf.Empty\x1a\x35.yamcs.protobuf.processing.ListProcessorTypesResponse\"\x1a\x8a\x92\x03\x16\n\x14/api/processor-types\x12\x8c\x01\n\x0eListProcessors\x12\x30.yamcs.protobuf.processing.ListProcessorsRequest\x1a\x31.yamcs.protobuf.processing.ListProcessorsResponse\"\x15\x8a\x92\x03\x11\n\x0f/api/processors\x12\x9b\x01\n\x0cGetProcessor\x12..yamcs.protobuf.processing.GetProcessorRequest\x1a-.yamcs.protobuf.yamcsManagement.ProcessorInfo\",\x8a\x92\x03(\n&/api/processors/{instance}/{processor}\x12\x8a\x01\n\x0f\x44\x65leteProcessor\x12\x31.yamcs.protobuf.processing.DeleteProcessorRequest\x1a\x16.google.protobuf.Empty\",\x8a\x92\x03(\"&/api/processors/{instance}/{processor}\x12\x89\x01\n\rEditProcessor\x12/.yamcs.protobuf.processing.EditProcessorRequest\x1a\x16.google.protobuf.Empty\"/\x8a\x92\x03+*&/api/processors/{instance}/{processor}:\x01*\x12v\n\x0f\x43reateProcessor\x12\x31.yamcs.protobuf.processing.CreateProcessorRequest\x1a\x16.google.protobuf.Empty\"\x18\x8a\x92\x03\x14\x1a\x0f/api/processors:\x01*\x12\xb0\x01\n\x11GetParameterValue\x12\x33.yamcs.protobuf.processing.GetParameterValueRequest\x1a%.yamcs.protobuf.pvalue.ParameterValue\"?\x8a\x92\x03;\n9/api/processors/{instance}/{processor}/parameters/{name*}\x12\xee\x01\n\x11SetParameterValue\x12\x33.yamcs.protobuf.processing.SetParameterValueRequest\x1a\x16.google.protobuf.Empty\"\x8b\x01\x8a\x92\x03\x86\x01\x12\x39/api/processors/{instance}/{processor}/parameters/{name*}:\x05valueZB\x1a\x39/api/processors/{instance}/{processor}/parameters/{name*}:\x05value\x12\xd5\x01\n\x17\x42\x61tchGetParameterValues\x12\x39.yamcs.protobuf.processing.BatchGetParameterValuesRequest\x1a:.yamcs.protobuf.processing.BatchGetParameterValuesResponse\"C\x8a\x92\x03?\x1a:/api/processors/{instance}/{processor}/parameters:batchGet:\x01*\x12\xb1\x01\n\x17\x42\x61tchSetParameterValues\x12\x39.yamcs.protobuf.processing.BatchSetParameterValuesRequest\x1a\x16.google.protobuf.Empty\"C\x8a\x92\x03?\x1a:/api/processors/{instance}/{processor}/parameters:batchSet:\x01*\x12\xb1\x01\n\x0cIssueCommand\x12..yamcs.protobuf.processing.IssueCommandRequest\x1a/.yamcs.protobuf.processing.IssueCommandResponse\"@\x8a\x92\x03<\x1a\x37/api/processors/{instance}/{processor}/commands/{name*}:\x01*\x12\xae\x01\n\x14UpdateCommandHistory\x12\x36.yamcs.protobuf.processing.UpdateCommandHistoryRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a=/api/processors/{instance}/{processor}/commandhistory/{name*}:\x01*B\'\n\x12org.yamcs.protobufB\x0fProcessingProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_LISTPROCESSORTYPESRESPONSE = _descriptor.Descriptor(
  name='ListProcessorTypesResponse',
  full_name='yamcs.protobuf.processing.ListProcessorTypesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='yamcs.protobuf.processing.ListProcessorTypesResponse.types', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=369,
)


_LISTPROCESSORSREQUEST = _descriptor.Descriptor(
  name='ListProcessorsRequest',
  full_name='yamcs.protobuf.processing.ListProcessorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.ListProcessorsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=412,
)


_LISTPROCESSORSRESPONSE = _descriptor.Descriptor(
  name='ListProcessorsResponse',
  full_name='yamcs.protobuf.processing.ListProcessorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='yamcs.protobuf.processing.ListProcessorsResponse.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=505,
)


_GETPROCESSORREQUEST = _descriptor.Descriptor(
  name='GetProcessorRequest',
  full_name='yamcs.protobuf.processing.GetProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=565,
)


_DELETEPROCESSORREQUEST = _descriptor.Descriptor(
  name='DeleteProcessorRequest',
  full_name='yamcs.protobuf.processing.DeleteProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.DeleteProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.DeleteProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=628,
)


_CREATEPROCESSORREQUEST = _descriptor.Descriptor(
  name='CreateProcessorRequest',
  full_name='yamcs.protobuf.processing.CreateProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.CreateProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.CreateProcessorRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='yamcs.protobuf.processing.CreateProcessorRequest.clientId', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.processing.CreateProcessorRequest.persistent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.processing.CreateProcessorRequest.type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.processing.CreateProcessorRequest.config', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=630,
  serialized_end=754,
)


_EDITPROCESSORREQUEST = _descriptor.Descriptor(
  name='EditProcessorRequest',
  full_name='yamcs.protobuf.processing.EditProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.EditProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.EditProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.processing.EditProcessorRequest.state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seek', full_name='yamcs.protobuf.processing.EditProcessorRequest.seek', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='yamcs.protobuf.processing.EditProcessorRequest.speed', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=888,
)


_GETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='GetParameterValueRequest',
  full_name='yamcs.protobuf.processing.GetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetParameterValueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetParameterValueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.GetParameterValueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.processing.GetParameterValueRequest.fromCache', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.processing.GetParameterValueRequest.timeout', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=1003,
)


_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.processing.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SetParameterValueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SetParameterValueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.SetParameterValueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.SetParameterValueRequest.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1120,
)


_BATCHGETPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='BatchGetParameterValuesRequest',
  full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.instance', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.processor', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.id', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.fromCache', index=3,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.timeout', index=4,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1271,
)


_BATCHGETPARAMETERVALUESRESPONSE = _descriptor.Descriptor(
  name='BatchGetParameterValuesResponse',
  full_name='yamcs.protobuf.processing.BatchGetParameterValuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.BatchGetParameterValuesResponse.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1273,
  serialized_end=1360,
)


_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1535,
  serialized_end=1642,
)

_BATCHSETPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='BatchSetParameterValuesRequest',
  full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.instance', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.processor', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.request', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1363,
  serialized_end=1642,
)


_ISSUECOMMANDREQUEST_ASSIGNMENT = _descriptor.Descriptor(
  name='Assignment',
  full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=1979,
)

_ISSUECOMMANDREQUEST = _descriptor.Descriptor(
  name='IssueCommandRequest',
  full_name='yamcs.protobuf.processing.IssueCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.IssueCommandRequest.instance', index=0,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.IssueCommandRequest.processor', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.IssueCommandRequest.name', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignment', full_name='yamcs.protobuf.processing.IssueCommandRequest.assignment', index=3,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.processing.IssueCommandRequest.origin', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.processing.IssueCommandRequest.sequenceNumber', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='yamcs.protobuf.processing.IssueCommandRequest.dryRun', index=6,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.processing.IssueCommandRequest.comment', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandOptions', full_name='yamcs.protobuf.processing.IssueCommandRequest.commandOptions', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ISSUECOMMANDREQUEST_ASSIGNMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1645,
  serialized_end=1979,
)


_ISSUECOMMANDRESPONSE = _descriptor.Descriptor(
  name='IssueCommandResponse',
  full_name='yamcs.protobuf.processing.IssueCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.IssueCommandResponse.id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.processing.IssueCommandResponse.generationTime', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.processing.IssueCommandResponse.origin', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.processing.IssueCommandResponse.sequenceNumber', index=3,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.processing.IssueCommandResponse.commandName', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.processing.IssueCommandResponse.source', index=5,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hex', full_name='yamcs.protobuf.processing.IssueCommandResponse.hex', index=6,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='yamcs.protobuf.processing.IssueCommandResponse.binary', index=7,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.processing.IssueCommandResponse.username', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.processing.IssueCommandResponse.queue', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1982,
  serialized_end=2207,
)


_UPDATECOMMANDHISTORYREQUEST = _descriptor.Descriptor(
  name='UpdateCommandHistoryRequest',
  full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.attributes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2210,
  serialized_end=2374,
)

_LISTPROCESSORSRESPONSE.fields_by_name['processors'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_EDITPROCESSORREQUEST.fields_by_name['seek'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_BATCHGETPARAMETERVALUESREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHGETPARAMETERVALUESRESPONSE.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.containing_type = _BATCHSETPARAMETERVALUESREQUEST
_BATCHSETPARAMETERVALUESREQUEST.fields_by_name['request'].message_type = _BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST
_ISSUECOMMANDREQUEST_ASSIGNMENT.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST.fields_by_name['assignment'].message_type = _ISSUECOMMANDREQUEST_ASSIGNMENT
_ISSUECOMMANDREQUEST.fields_by_name['commandOptions'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDOPTIONS
_ISSUECOMMANDRESPONSE.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPDATECOMMANDHISTORYREQUEST.fields_by_name['attributes'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYATTRIBUTE
DESCRIPTOR.message_types_by_name['ListProcessorTypesResponse'] = _LISTPROCESSORTYPESRESPONSE
DESCRIPTOR.message_types_by_name['ListProcessorsRequest'] = _LISTPROCESSORSREQUEST
DESCRIPTOR.message_types_by_name['ListProcessorsResponse'] = _LISTPROCESSORSRESPONSE
DESCRIPTOR.message_types_by_name['GetProcessorRequest'] = _GETPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['DeleteProcessorRequest'] = _DELETEPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['CreateProcessorRequest'] = _CREATEPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['EditProcessorRequest'] = _EDITPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['GetParameterValueRequest'] = _GETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetParameterValueRequest'] = _SETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParameterValuesRequest'] = _BATCHGETPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParameterValuesResponse'] = _BATCHGETPARAMETERVALUESRESPONSE
DESCRIPTOR.message_types_by_name['BatchSetParameterValuesRequest'] = _BATCHSETPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandRequest'] = _ISSUECOMMANDREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandResponse'] = _ISSUECOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateCommandHistoryRequest'] = _UPDATECOMMANDHISTORYREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListProcessorTypesResponse = _reflection.GeneratedProtocolMessageType('ListProcessorTypesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORTYPESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorTypesResponse)
  })
_sym_db.RegisterMessage(ListProcessorTypesResponse)

ListProcessorsRequest = _reflection.GeneratedProtocolMessageType('ListProcessorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORSREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorsRequest)
  })
_sym_db.RegisterMessage(ListProcessorsRequest)

ListProcessorsResponse = _reflection.GeneratedProtocolMessageType('ListProcessorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORSRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorsResponse)
  })
_sym_db.RegisterMessage(ListProcessorsResponse)

GetProcessorRequest = _reflection.GeneratedProtocolMessageType('GetProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetProcessorRequest)
  })
_sym_db.RegisterMessage(GetProcessorRequest)

DeleteProcessorRequest = _reflection.GeneratedProtocolMessageType('DeleteProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.DeleteProcessorRequest)
  })
_sym_db.RegisterMessage(DeleteProcessorRequest)

CreateProcessorRequest = _reflection.GeneratedProtocolMessageType('CreateProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.CreateProcessorRequest)
  })
_sym_db.RegisterMessage(CreateProcessorRequest)

EditProcessorRequest = _reflection.GeneratedProtocolMessageType('EditProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.EditProcessorRequest)
  })
_sym_db.RegisterMessage(EditProcessorRequest)

GetParameterValueRequest = _reflection.GeneratedProtocolMessageType('GetParameterValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERVALUEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetParameterValueRequest)
  })
_sym_db.RegisterMessage(GetParameterValueRequest)

SetParameterValueRequest = _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPARAMETERVALUEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SetParameterValueRequest)
  })
_sym_db.RegisterMessage(SetParameterValueRequest)

BatchGetParameterValuesRequest = _reflection.GeneratedProtocolMessageType('BatchGetParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchGetParameterValuesRequest)
  })
_sym_db.RegisterMessage(BatchGetParameterValuesRequest)

BatchGetParameterValuesResponse = _reflection.GeneratedProtocolMessageType('BatchGetParameterValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERVALUESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchGetParameterValuesResponse)
  })
_sym_db.RegisterMessage(BatchGetParameterValuesResponse)

BatchSetParameterValuesRequest = _reflection.GeneratedProtocolMessageType('BatchSetParameterValuesRequest', (_message.Message,), {

  'SetParameterValueRequest' : _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), {
    'DESCRIPTOR' : _BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest)
    })
  ,
  'DESCRIPTOR' : _BATCHSETPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchSetParameterValuesRequest)
  })
_sym_db.RegisterMessage(BatchSetParameterValuesRequest)
_sym_db.RegisterMessage(BatchSetParameterValuesRequest.SetParameterValueRequest)

IssueCommandRequest = _reflection.GeneratedProtocolMessageType('IssueCommandRequest', (_message.Message,), {

  'Assignment' : _reflection.GeneratedProtocolMessageType('Assignment', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_ASSIGNMENT,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandRequest.Assignment)
    })
  ,
  'DESCRIPTOR' : _ISSUECOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandRequest)
  })
_sym_db.RegisterMessage(IssueCommandRequest)
_sym_db.RegisterMessage(IssueCommandRequest.Assignment)

IssueCommandResponse = _reflection.GeneratedProtocolMessageType('IssueCommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISSUECOMMANDRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandResponse)
  })
_sym_db.RegisterMessage(IssueCommandResponse)

UpdateCommandHistoryRequest = _reflection.GeneratedProtocolMessageType('UpdateCommandHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMANDHISTORYREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.UpdateCommandHistoryRequest)
  })
_sym_db.RegisterMessage(UpdateCommandHistoryRequest)


DESCRIPTOR._options = None

_PROCESSINGAPI = _descriptor.ServiceDescriptor(
  name='ProcessingApi',
  full_name='yamcs.protobuf.processing.ProcessingApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2377,
  serialized_end=4396,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListProcessorTypes',
    full_name='yamcs.protobuf.processing.ProcessingApi.ListProcessorTypes',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTPROCESSORTYPESRESPONSE,
    serialized_options=b'\212\222\003\026\n\024/api/processor-types',
  ),
  _descriptor.MethodDescriptor(
    name='ListProcessors',
    full_name='yamcs.protobuf.processing.ProcessingApi.ListProcessors',
    index=1,
    containing_service=None,
    input_type=_LISTPROCESSORSREQUEST,
    output_type=_LISTPROCESSORSRESPONSE,
    serialized_options=b'\212\222\003\021\n\017/api/processors',
  ),
  _descriptor.MethodDescriptor(
    name='GetProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetProcessor',
    index=2,
    containing_service=None,
    input_type=_GETPROCESSORREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO,
    serialized_options=b'\212\222\003(\n&/api/processors/{instance}/{processor}',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.DeleteProcessor',
    index=3,
    containing_service=None,
    input_type=_DELETEPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003(\"&/api/processors/{instance}/{processor}',
  ),
  _descriptor.MethodDescriptor(
    name='EditProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.EditProcessor',
    index=4,
    containing_service=None,
    input_type=_EDITPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003+*&/api/processors/{instance}/{processor}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='CreateProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.CreateProcessor',
    index=5,
    containing_service=None,
    input_type=_CREATEPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003\024\032\017/api/processors:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='GetParameterValue',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetParameterValue',
    index=6,
    containing_service=None,
    input_type=_GETPARAMETERVALUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE,
    serialized_options=b'\212\222\003;\n9/api/processors/{instance}/{processor}/parameters/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='SetParameterValue',
    full_name='yamcs.protobuf.processing.ProcessingApi.SetParameterValue',
    index=7,
    containing_service=None,
    input_type=_SETPARAMETERVALUEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003\206\001\0229/api/processors/{instance}/{processor}/parameters/{name*}:\005valueZB\0329/api/processors/{instance}/{processor}/parameters/{name*}:\005value',
  ),
  _descriptor.MethodDescriptor(
    name='BatchGetParameterValues',
    full_name='yamcs.protobuf.processing.ProcessingApi.BatchGetParameterValues',
    index=8,
    containing_service=None,
    input_type=_BATCHGETPARAMETERVALUESREQUEST,
    output_type=_BATCHGETPARAMETERVALUESRESPONSE,
    serialized_options=b'\212\222\003?\032:/api/processors/{instance}/{processor}/parameters:batchGet:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='BatchSetParameterValues',
    full_name='yamcs.protobuf.processing.ProcessingApi.BatchSetParameterValues',
    index=9,
    containing_service=None,
    input_type=_BATCHSETPARAMETERVALUESREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003?\032:/api/processors/{instance}/{processor}/parameters:batchSet:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='IssueCommand',
    full_name='yamcs.protobuf.processing.ProcessingApi.IssueCommand',
    index=10,
    containing_service=None,
    input_type=_ISSUECOMMANDREQUEST,
    output_type=_ISSUECOMMANDRESPONSE,
    serialized_options=b'\212\222\003<\0327/api/processors/{instance}/{processor}/commands/{name*}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCommandHistory',
    full_name='yamcs.protobuf.processing.ProcessingApi.UpdateCommandHistory',
    index=11,
    containing_service=None,
    input_type=_UPDATECOMMANDHISTORYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003B\032=/api/processors/{instance}/{processor}/commandhistory/{name*}:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSINGAPI)

DESCRIPTOR.services_by_name['ProcessingApi'] = _PROCESSINGAPI

# @@protoc_insertion_point(module_scope)



import pkg_resources
import requests
import six
import urllib3
from google.protobuf.message import DecodeError

from yamcs.api import exception_pb2
from yamcs.core.exceptions import (ConnectionFailure, NotFound, Unauthorized,
                                   YamcsError)


class BaseClient(object):

    credentials = None

    def __init__(self, address, tls=False, credentials=None, user_agent=None,
                 on_token_update=None, tls_verify=True):
        if ':' in address:
            self.address = address
        else:
            self.address = address + ':8090'

        if tls:
            self.auth_root = 'https://{}/auth'.format(self.address)
            self.api_root = 'https://{}/api'.format(self.address)
            self.ws_root = 'wss://{}/_websocket'.format(self.address)
            self.ws_root_v2 = 'wss://{}/api/websocket'.format(self.address)
        else:
            self.auth_root = 'http://{}/auth'.format(self.address)
            self.api_root = 'http://{}/api'.format(self.address)
            self.ws_root = 'ws://{}/_websocket'.format(self.address)
            self.ws_root_v2 = 'ws://{}/api/websocket'.format(self.address)

        self.session = requests.Session()
        if not tls_verify:
            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
            self.session.verify = False

        if credentials:
            self.credentials = credentials.login(
                self.session, self.auth_root, on_token_update)

        if not user_agent:
            dist = pkg_resources.get_distribution('yamcs-client')
            user_agent = 'yamcs-python-client v' + dist.version
        self.session.headers.update({'User-Agent': user_agent})

    def get_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('get', path, **kwargs)

    def put_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Content-Type'] = 'application/protobuf'
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('put', path, **kwargs)

    def patch_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Content-Type'] = 'application/protobuf'
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('patch', path, **kwargs)

    def post_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Content-Type'] = 'application/protobuf'
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('post', path, **kwargs)

    def delete_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('delete', path, **kwargs)

    def request(self, method, path, **kwargs):
        path = '{}{}'.format(self.api_root, path)

        if self.credentials:
            self.credentials.before_request(self.session, self.auth_root)

        try:
            response = self.session.request(method, path, **kwargs)
        except requests.exceptions.SSLError as sslError:
            msg = 'Connection to {} failed: {}'.format(self.address, sslError)
            six.raise_from(ConnectionFailure(msg), None)
        except requests.exceptions.ConnectionError as e:
            raise ConnectionFailure('Connection to {} failed: {}'.format(
                self.address, e))

        if 200 <= response.status_code < 300:
            return response

        exception_message = exception_pb2.ExceptionMessage()
        try:
            exception_message.ParseFromString(response.content)
        except DecodeError:
            pass

        if response.status_code == 401:
            raise Unauthorized('401 Client Error: Unauthorized')
        elif response.status_code == 404:
            raise NotFound('404 Client Error: {}'.format(
                getattr(exception_message, 'msg')))
        elif 400 <= response.status_code < 500:
            raise YamcsError('{} Client Error: {}'.format(
                response.status_code, getattr(exception_message, 'msg')))
        raise YamcsError('{} Server Error: {}'.format(
            response.status_code, getattr(exception_message, 'msg')))



from __future__ import print_function

import logging
from collections import OrderedDict
from datetime import datetime, timedelta

from yamcs.protobuf import yamcs_pb2


def to_isostring(dt):
    """
    Converts the given datetime to an ISO String.
    This assumes the datetime is UTC.
    """
    if dt.tzinfo is not None and dt.tzinfo.utcoffset(dt) > timedelta(0):
        logging.warning('Warning: aware datetimes are interpreted as if they were naive')

    # -3 to change microseconds to milliseconds
    return dt.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3] + 'Z'


def parse_isostring(isostring):
    """
    Parse the ISO String to a native ``datetime``.
    """
    if not isostring:
        return None
    return datetime.strptime(isostring.replace('Z', 'GMT'),
                             '%Y-%m-%dT%H:%M:%S.%f%Z')


def parse_value(proto):
    """
    Convers a Protobuf `Value` from the API into a python native value
    """
    if proto.type == yamcs_pb2.Value.FLOAT:
        return proto.floatValue
    elif proto.type == yamcs_pb2.Value.DOUBLE:
        return proto.doubleValue
    elif proto.type == yamcs_pb2.Value.SINT32:
        return proto.sint32Value
    elif proto.type == yamcs_pb2.Value.UINT32:
        return proto.uint32Value
    elif proto.type == yamcs_pb2.Value.BINARY:
        return proto.binaryValue
    elif proto.type == yamcs_pb2.Value.TIMESTAMP:
        # Don't use the actual 'timestampValue' field, it contains a number
        # that is difficult to interpret on the client. Instead parse from
        # the ISO String also set by Yamcs.
        return parse_isostring(proto.stringValue)
    elif proto.type == yamcs_pb2.Value.STRING:
        return proto.stringValue
    elif proto.type == yamcs_pb2.Value.UINT64:
        return proto.uint64Value
    elif proto.type == yamcs_pb2.Value.SINT64:
        return proto.sint64Value
    elif proto.type == yamcs_pb2.Value.BOOLEAN:
        return proto.booleanValue
    elif proto.type == yamcs_pb2.Value.ENUMERATED:
        return proto.stringValue
    elif proto.type == yamcs_pb2.Value.ARRAY:
        return [parse_value(v) for v in proto.arrayValue]
    elif proto.type == yamcs_pb2.Value.AGGREGATE:
        tuples = zip(proto.aggregateValue.name, proto.aggregateValue.value)
        return OrderedDict(map(lambda x: (x[0], parse_value(x[1])), tuples))
    else:
        logging.warning('Unrecognized value type for update %s', proto)
        return None


def adapt_name_for_rest(name):
    """
    Modifies a user-provided name for use in API calls.
    Basically we want an alias like 'MDB:OPS Name/SIMULATOR_BatteryVoltage2'
    to be prepended with a slash.
    """
    if name.startswith('/'):
        return name
    elif not '/' in name:
        raise ValueError('Provided name is not a fully-qualified XTCE name.')
    return '/' + name



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/api/httpbody.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/api/httpbody.proto',
  package='yamcs.api',
  syntax='proto2',
  serialized_options=b'\n\rorg.yamcs.apiB\rHttpBodyProtoP\001',
  serialized_pb=b'\n\x18yamcs/api/httpbody.proto\x12\tyamcs.api\"@\n\x08HttpBody\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42 \n\rorg.yamcs.apiB\rHttpBodyProtoP\x01'
)




_HTTPBODY = _descriptor.Descriptor(
  name='HttpBody',
  full_name='yamcs.api.HttpBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_type', full_name='yamcs.api.HttpBody.content_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='yamcs.api.HttpBody.filename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.api.HttpBody.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=103,
)

DESCRIPTOR.message_types_by_name['HttpBody'] = _HTTPBODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpBody = _reflection.GeneratedProtocolMessageType('HttpBody', (_message.Message,), {
  'DESCRIPTOR' : _HTTPBODY,
  '__module__' : 'yamcs.api.httpbody_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.HttpBody)
  })
_sym_db.RegisterMessage(HttpBody)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/command_history_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/command_history_service.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\032CommandHistoryServiceProtoP\001',
  serialized_pb=b'\n7yamcs/protobuf/commanding/command_history_service.proto\x12\x19yamcs.protobuf.commanding\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/commanding/commanding.proto\"\xc0\x01\n\x13ListCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0b\n\x03pos\x18\x02 \x01(\x03\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\r\n\x05order\x18\x04 \x01(\t\x12\t\n\x01q\x18\x05 \x01(\t\x12\x0c\n\x04next\x18\x06 \x01(\t\x12)\n\x05start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"p\n\x14ListCommandsResponse\x12=\n\x05\x65ntry\x18\x01 \x03(\x0b\x32..yamcs.protobuf.commanding.CommandHistoryEntry\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"1\n\x11GetCommandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\x8c\x01\n\x15StreamCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x03(\t2\xf6\x03\n\x11\x43ommandHistoryApi\x12\x97\x01\n\x0cListCommands\x12..yamcs.protobuf.commanding.ListCommandsRequest\x1a/.yamcs.protobuf.commanding.ListCommandsResponse\"&\x8a\x92\x03\"\n /api/archive/{instance}/commands\x12\x97\x01\n\nGetCommand\x12,.yamcs.protobuf.commanding.GetCommandRequest\x1a..yamcs.protobuf.commanding.CommandHistoryEntry\"+\x8a\x92\x03\'\n%/api/archive/{instance}/commands/{id}\x12\xac\x01\n\x0eStreamCommands\x12\x30.yamcs.protobuf.commanding.StreamCommandsRequest\x1a..yamcs.protobuf.commanding.CommandHistoryEntry\"6\x8a\x92\x03\x32\x1a-/api/stream-archive/{instance}:streamCommands:\x01*0\x01\x42\x32\n\x12org.yamcs.protobufB\x1a\x43ommandHistoryServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,])




_LISTCOMMANDSREQUEST = _descriptor.Descriptor(
  name='ListCommandsRequest',
  full_name='yamcs.protobuf.commanding.ListCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.commanding.ListCommandsRequest.pos', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.commanding.ListCommandsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.commanding.ListCommandsRequest.order', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.commanding.ListCommandsRequest.q', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.commanding.ListCommandsRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.commanding.ListCommandsRequest.start', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.commanding.ListCommandsRequest.stop', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=385,
)


_LISTCOMMANDSRESPONSE = _descriptor.Descriptor(
  name='ListCommandsResponse',
  full_name='yamcs.protobuf.commanding.ListCommandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.commanding.ListCommandsResponse.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.commanding.ListCommandsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=499,
)


_GETCOMMANDREQUEST = _descriptor.Descriptor(
  name='GetCommandRequest',
  full_name='yamcs.protobuf.commanding.GetCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.GetCommandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.GetCommandRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=550,
)


_STREAMCOMMANDSREQUEST = _descriptor.Descriptor(
  name='StreamCommandsRequest',
  full_name='yamcs.protobuf.commanding.StreamCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.name', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=693,
)

_LISTCOMMANDSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMMANDSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMMANDSRESPONSE.fields_by_name['entry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY
_STREAMCOMMANDSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMMANDSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListCommandsRequest'] = _LISTCOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['ListCommandsResponse'] = _LISTCOMMANDSRESPONSE
DESCRIPTOR.message_types_by_name['GetCommandRequest'] = _GETCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['StreamCommandsRequest'] = _STREAMCOMMANDSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListCommandsRequest = _reflection.GeneratedProtocolMessageType('ListCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.command_history_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListCommandsRequest)
  })
_sym_db.RegisterMessage(ListCommandsRequest)

ListCommandsResponse = _reflection.GeneratedProtocolMessageType('ListCommandsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.command_history_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListCommandsResponse)
  })
_sym_db.RegisterMessage(ListCommandsResponse)

GetCommandRequest = _reflection.GeneratedProtocolMessageType('GetCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.command_history_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.GetCommandRequest)
  })
_sym_db.RegisterMessage(GetCommandRequest)

StreamCommandsRequest = _reflection.GeneratedProtocolMessageType('StreamCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.command_history_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.StreamCommandsRequest)
  })
_sym_db.RegisterMessage(StreamCommandsRequest)


DESCRIPTOR._options = None

_COMMANDHISTORYAPI = _descriptor.ServiceDescriptor(
  name='CommandHistoryApi',
  full_name='yamcs.protobuf.commanding.CommandHistoryApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=696,
  serialized_end=1198,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListCommands',
    full_name='yamcs.protobuf.commanding.CommandHistoryApi.ListCommands',
    index=0,
    containing_service=None,
    input_type=_LISTCOMMANDSREQUEST,
    output_type=_LISTCOMMANDSRESPONSE,
    serialized_options=b'\212\222\003\"\n /api/archive/{instance}/commands',
  ),
  _descriptor.MethodDescriptor(
    name='GetCommand',
    full_name='yamcs.protobuf.commanding.CommandHistoryApi.GetCommand',
    index=1,
    containing_service=None,
    input_type=_GETCOMMANDREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY,
    serialized_options=b'\212\222\003\'\n%/api/archive/{instance}/commands/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='StreamCommands',
    full_name='yamcs.protobuf.commanding.CommandHistoryApi.StreamCommands',
    index=2,
    containing_service=None,
    input_type=_STREAMCOMMANDSREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY,
    serialized_options=b'\212\222\0032\032-/api/stream-archive/{instance}:streamCommands:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMANDHISTORYAPI)

DESCRIPTOR.services_by_name['CommandHistoryApi'] = _COMMANDHISTORYAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/alarms/alarms_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.alarms import alarms_pb2 as yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/alarms/alarms_service.proto',
  package='yamcs.protobuf.alarms',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\022AlarmsServiceProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/alarms/alarms_service.proto\x12\x15yamcs.protobuf.alarms\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\"yamcs/protobuf/alarms/alarms.proto\"\xa5\x01\n\x11ListAlarmsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0b\n\x03pos\x18\x02 \x01(\x03\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05order\x18\x06 \x01(\t\"F\n\x12ListAlarmsResponse\x12\x30\n\x06\x61larms\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.alarms.AlarmData\"\xd1\x01\n\x1aListParameterAlarmsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tparameter\x18\x02 \x01(\t\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\r\n\x05limit\x18\x04 \x01(\x05\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05order\x18\x07 \x01(\t\x12\x0e\n\x06\x64\x65tail\x18\x08 \x01(\x08\"O\n\x1bListParameterAlarmsResponse\x12\x30\n\x06\x61larms\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.alarms.AlarmData\"A\n\x1aListProcessorAlarmsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"O\n\x1bListProcessorAlarmsResponse\x12\x30\n\x06\x61larms\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.alarms.AlarmData\"\x8d\x01\n\x10\x45\x64itAlarmRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06seqnum\x18\x04 \x01(\r\x12\r\n\x05state\x18\x05 \x01(\t\x12\x0f\n\x07\x63omment\x18\x06 \x01(\t\x12\x16\n\x0eshelveDuration\x18\x07 \x01(\x04\x32\x93\x05\n\tAlarmsApi\x12\x87\x01\n\nListAlarms\x12(.yamcs.protobuf.alarms.ListAlarmsRequest\x1a).yamcs.protobuf.alarms.ListAlarmsResponse\"$\x8a\x92\x03 \n\x1e/api/archive/{instance}/alarms\x12\xaf\x01\n\x13ListParameterAlarms\x12\x31.yamcs.protobuf.alarms.ListParameterAlarmsRequest\x1a\x32.yamcs.protobuf.alarms.ListParameterAlarmsResponse\"1\x8a\x92\x03-\n+/api/archive/{instance}/alarms/{parameter*}\x12\xb1\x01\n\x13ListProcessorAlarms\x12\x31.yamcs.protobuf.alarms.ListProcessorAlarmsRequest\x1a\x32.yamcs.protobuf.alarms.ListProcessorAlarmsResponse\"3\x8a\x92\x03/\n-/api/processors/{instance}/{processor}/alarms\x12\x95\x01\n\tEditAlarm\x12\'.yamcs.protobuf.alarms.EditAlarmRequest\x1a\x16.google.protobuf.Empty\"G\x8a\x92\x03\x43*>/api/processors/{instance}/{processor}/alarms/{name*}/{seqnum}:\x01*B*\n\x12org.yamcs.protobufB\x12\x41larmsServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2.DESCRIPTOR,])




_LISTALARMSREQUEST = _descriptor.Descriptor(
  name='ListAlarmsRequest',
  full_name='yamcs.protobuf.alarms.ListAlarmsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.alarms.ListAlarmsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.alarms.ListAlarmsRequest.pos', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.alarms.ListAlarmsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.alarms.ListAlarmsRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.alarms.ListAlarmsRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.alarms.ListAlarmsRequest.order', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=362,
)


_LISTALARMSRESPONSE = _descriptor.Descriptor(
  name='ListAlarmsResponse',
  full_name='yamcs.protobuf.alarms.ListAlarmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alarms', full_name='yamcs.protobuf.alarms.ListAlarmsResponse.alarms', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=434,
)


_LISTPARAMETERALARMSREQUEST = _descriptor.Descriptor(
  name='ListParameterAlarmsRequest',
  full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest.parameter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest.pos', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest.start', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest.stop', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest.order', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail', full_name='yamcs.protobuf.alarms.ListParameterAlarmsRequest.detail', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=646,
)


_LISTPARAMETERALARMSRESPONSE = _descriptor.Descriptor(
  name='ListParameterAlarmsResponse',
  full_name='yamcs.protobuf.alarms.ListParameterAlarmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alarms', full_name='yamcs.protobuf.alarms.ListParameterAlarmsResponse.alarms', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=727,
)


_LISTPROCESSORALARMSREQUEST = _descriptor.Descriptor(
  name='ListProcessorAlarmsRequest',
  full_name='yamcs.protobuf.alarms.ListProcessorAlarmsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.alarms.ListProcessorAlarmsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.alarms.ListProcessorAlarmsRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=794,
)


_LISTPROCESSORALARMSRESPONSE = _descriptor.Descriptor(
  name='ListProcessorAlarmsResponse',
  full_name='yamcs.protobuf.alarms.ListProcessorAlarmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alarms', full_name='yamcs.protobuf.alarms.ListProcessorAlarmsResponse.alarms', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=875,
)


_EDITALARMREQUEST = _descriptor.Descriptor(
  name='EditAlarmRequest',
  full_name='yamcs.protobuf.alarms.EditAlarmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.alarms.EditAlarmRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.alarms.EditAlarmRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.alarms.EditAlarmRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqnum', full_name='yamcs.protobuf.alarms.EditAlarmRequest.seqnum', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.alarms.EditAlarmRequest.state', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.alarms.EditAlarmRequest.comment', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shelveDuration', full_name='yamcs.protobuf.alarms.EditAlarmRequest.shelveDuration', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=1019,
)

_LISTALARMSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTALARMSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTALARMSRESPONSE.fields_by_name['alarms'].message_type = yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2._ALARMDATA
_LISTPARAMETERALARMSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERALARMSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERALARMSRESPONSE.fields_by_name['alarms'].message_type = yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2._ALARMDATA
_LISTPROCESSORALARMSRESPONSE.fields_by_name['alarms'].message_type = yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2._ALARMDATA
DESCRIPTOR.message_types_by_name['ListAlarmsRequest'] = _LISTALARMSREQUEST
DESCRIPTOR.message_types_by_name['ListAlarmsResponse'] = _LISTALARMSRESPONSE
DESCRIPTOR.message_types_by_name['ListParameterAlarmsRequest'] = _LISTPARAMETERALARMSREQUEST
DESCRIPTOR.message_types_by_name['ListParameterAlarmsResponse'] = _LISTPARAMETERALARMSRESPONSE
DESCRIPTOR.message_types_by_name['ListProcessorAlarmsRequest'] = _LISTPROCESSORALARMSREQUEST
DESCRIPTOR.message_types_by_name['ListProcessorAlarmsResponse'] = _LISTPROCESSORALARMSRESPONSE
DESCRIPTOR.message_types_by_name['EditAlarmRequest'] = _EDITALARMREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAlarmsRequest = _reflection.GeneratedProtocolMessageType('ListAlarmsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALARMSREQUEST,
  '__module__' : 'yamcs.protobuf.alarms.alarms_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ListAlarmsRequest)
  })
_sym_db.RegisterMessage(ListAlarmsRequest)

ListAlarmsResponse = _reflection.GeneratedProtocolMessageType('ListAlarmsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALARMSRESPONSE,
  '__module__' : 'yamcs.protobuf.alarms.alarms_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ListAlarmsResponse)
  })
_sym_db.RegisterMessage(ListAlarmsResponse)

ListParameterAlarmsRequest = _reflection.GeneratedProtocolMessageType('ListParameterAlarmsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERALARMSREQUEST,
  '__module__' : 'yamcs.protobuf.alarms.alarms_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ListParameterAlarmsRequest)
  })
_sym_db.RegisterMessage(ListParameterAlarmsRequest)

ListParameterAlarmsResponse = _reflection.GeneratedProtocolMessageType('ListParameterAlarmsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERALARMSRESPONSE,
  '__module__' : 'yamcs.protobuf.alarms.alarms_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ListParameterAlarmsResponse)
  })
_sym_db.RegisterMessage(ListParameterAlarmsResponse)

ListProcessorAlarmsRequest = _reflection.GeneratedProtocolMessageType('ListProcessorAlarmsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORALARMSREQUEST,
  '__module__' : 'yamcs.protobuf.alarms.alarms_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ListProcessorAlarmsRequest)
  })
_sym_db.RegisterMessage(ListProcessorAlarmsRequest)

ListProcessorAlarmsResponse = _reflection.GeneratedProtocolMessageType('ListProcessorAlarmsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORALARMSRESPONSE,
  '__module__' : 'yamcs.protobuf.alarms.alarms_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ListProcessorAlarmsResponse)
  })
_sym_db.RegisterMessage(ListProcessorAlarmsResponse)

EditAlarmRequest = _reflection.GeneratedProtocolMessageType('EditAlarmRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITALARMREQUEST,
  '__module__' : 'yamcs.protobuf.alarms.alarms_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.EditAlarmRequest)
  })
_sym_db.RegisterMessage(EditAlarmRequest)


DESCRIPTOR._options = None

_ALARMSAPI = _descriptor.ServiceDescriptor(
  name='AlarmsApi',
  full_name='yamcs.protobuf.alarms.AlarmsApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1022,
  serialized_end=1681,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListAlarms',
    full_name='yamcs.protobuf.alarms.AlarmsApi.ListAlarms',
    index=0,
    containing_service=None,
    input_type=_LISTALARMSREQUEST,
    output_type=_LISTALARMSRESPONSE,
    serialized_options=b'\212\222\003 \n\036/api/archive/{instance}/alarms',
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterAlarms',
    full_name='yamcs.protobuf.alarms.AlarmsApi.ListParameterAlarms',
    index=1,
    containing_service=None,
    input_type=_LISTPARAMETERALARMSREQUEST,
    output_type=_LISTPARAMETERALARMSRESPONSE,
    serialized_options=b'\212\222\003-\n+/api/archive/{instance}/alarms/{parameter*}',
  ),
  _descriptor.MethodDescriptor(
    name='ListProcessorAlarms',
    full_name='yamcs.protobuf.alarms.AlarmsApi.ListProcessorAlarms',
    index=2,
    containing_service=None,
    input_type=_LISTPROCESSORALARMSREQUEST,
    output_type=_LISTPROCESSORALARMSRESPONSE,
    serialized_options=b'\212\222\003/\n-/api/processors/{instance}/{processor}/alarms',
  ),
  _descriptor.MethodDescriptor(
    name='EditAlarm',
    full_name='yamcs.protobuf.alarms.AlarmsApi.EditAlarm',
    index=3,
    containing_service=None,
    input_type=_EDITALARMREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003C*>/api/processors/{instance}/{processor}/alarms/{name*}/{seqnum}:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_ALARMSAPI)

DESCRIPTOR.services_by_name['AlarmsApi'] = _ALARMSAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/queue_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/queue_service.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\021QueueServiceProtoP\001',
  serialized_pb=b'\n-yamcs/protobuf/commanding/queue_service.proto\x12\x19yamcs.protobuf.commanding\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/commanding/commanding.proto\"8\n\x11ListQueuesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"Q\n\x12ListQueuesResponse\x12;\n\x06queues\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.commanding.CommandQueueInfo\"D\n\x0fGetQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"T\n\x10\x45\x64itQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\"L\n\x17ListQueueEntriesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"Y\n\x18ListQueueEntriesResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\"g\n\x15\x45\x64itQueueEntryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04uuid\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t2\xe5\x06\n\x08QueueApi\x12\x9e\x01\n\nListQueues\x12,.yamcs.protobuf.commanding.ListQueuesRequest\x1a-.yamcs.protobuf.commanding.ListQueuesResponse\"3\x8a\x92\x03/\n-/api/processors/{instance}/{processor}/queues\x12\x9f\x01\n\x08GetQueue\x12*.yamcs.protobuf.commanding.GetQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\":\x8a\x92\x03\x36\n4/api/processors/{instance}/{processor}/queues/{name}\x12\xa6\x01\n\x0bUpdateQueue\x12+.yamcs.protobuf.commanding.EditQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\"=\x8a\x92\x03\x39*4/api/processors/{instance}/{processor}/queues/{name}:\x01*\x12\xbf\x01\n\x10ListQueueEntries\x12\x32.yamcs.protobuf.commanding.ListQueueEntriesRequest\x1a\x33.yamcs.protobuf.commanding.ListQueueEntriesResponse\"B\x8a\x92\x03>\n</api/processors/{instance}/{processor}/queues/{name}/entries\x12\xaa\x01\n\x10UpdateQueueEntry\x12\x30.yamcs.protobuf.commanding.EditQueueEntryRequest\x1a\x16.google.protobuf.Empty\"L\x8a\x92\x03H*C/api/processors/{instance}/{processor}/queues/{name}/entries/{uuid}:\x01*B)\n\x12org.yamcs.protobufB\x11QueueServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,])




_LISTQUEUESREQUEST = _descriptor.Descriptor(
  name='ListQueuesRequest',
  full_name='yamcs.protobuf.commanding.ListQueuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListQueuesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.ListQueuesRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=234,
)


_LISTQUEUESRESPONSE = _descriptor.Descriptor(
  name='ListQueuesResponse',
  full_name='yamcs.protobuf.commanding.ListQueuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queues', full_name='yamcs.protobuf.commanding.ListQueuesResponse.queues', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=317,
)


_GETQUEUEREQUEST = _descriptor.Descriptor(
  name='GetQueueRequest',
  full_name='yamcs.protobuf.commanding.GetQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.GetQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.GetQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.GetQueueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=387,
)


_EDITQUEUEREQUEST = _descriptor.Descriptor(
  name='EditQueueRequest',
  full_name='yamcs.protobuf.commanding.EditQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.EditQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.EditQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.EditQueueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.commanding.EditQueueRequest.state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=473,
)


_LISTQUEUEENTRIESREQUEST = _descriptor.Descriptor(
  name='ListQueueEntriesRequest',
  full_name='yamcs.protobuf.commanding.ListQueueEntriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListQueueEntriesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.ListQueueEntriesRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.ListQueueEntriesRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=551,
)


_LISTQUEUEENTRIESRESPONSE = _descriptor.Descriptor(
  name='ListQueueEntriesResponse',
  full_name='yamcs.protobuf.commanding.ListQueueEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='yamcs.protobuf.commanding.ListQueueEntriesResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=642,
)


_EDITQUEUEENTRYREQUEST = _descriptor.Descriptor(
  name='EditQueueEntryRequest',
  full_name='yamcs.protobuf.commanding.EditQueueEntryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.state', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=747,
)

_LISTQUEUESRESPONSE.fields_by_name['queues'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO
_LISTQUEUEENTRIESRESPONSE.fields_by_name['entries'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEENTRY
DESCRIPTOR.message_types_by_name['ListQueuesRequest'] = _LISTQUEUESREQUEST
DESCRIPTOR.message_types_by_name['ListQueuesResponse'] = _LISTQUEUESRESPONSE
DESCRIPTOR.message_types_by_name['GetQueueRequest'] = _GETQUEUEREQUEST
DESCRIPTOR.message_types_by_name['EditQueueRequest'] = _EDITQUEUEREQUEST
DESCRIPTOR.message_types_by_name['ListQueueEntriesRequest'] = _LISTQUEUEENTRIESREQUEST
DESCRIPTOR.message_types_by_name['ListQueueEntriesResponse'] = _LISTQUEUEENTRIESRESPONSE
DESCRIPTOR.message_types_by_name['EditQueueEntryRequest'] = _EDITQUEUEENTRYREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListQueuesRequest = _reflection.GeneratedProtocolMessageType('ListQueuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUESREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueuesRequest)
  })
_sym_db.RegisterMessage(ListQueuesRequest)

ListQueuesResponse = _reflection.GeneratedProtocolMessageType('ListQueuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUESRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueuesResponse)
  })
_sym_db.RegisterMessage(ListQueuesResponse)

GetQueueRequest = _reflection.GeneratedProtocolMessageType('GetQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUEUEREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.GetQueueRequest)
  })
_sym_db.RegisterMessage(GetQueueRequest)

EditQueueRequest = _reflection.GeneratedProtocolMessageType('EditQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITQUEUEREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.EditQueueRequest)
  })
_sym_db.RegisterMessage(EditQueueRequest)

ListQueueEntriesRequest = _reflection.GeneratedProtocolMessageType('ListQueueEntriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUEENTRIESREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueueEntriesRequest)
  })
_sym_db.RegisterMessage(ListQueueEntriesRequest)

ListQueueEntriesResponse = _reflection.GeneratedProtocolMessageType('ListQueueEntriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUEENTRIESRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueueEntriesResponse)
  })
_sym_db.RegisterMessage(ListQueueEntriesResponse)

EditQueueEntryRequest = _reflection.GeneratedProtocolMessageType('EditQueueEntryRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITQUEUEENTRYREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.EditQueueEntryRequest)
  })
_sym_db.RegisterMessage(EditQueueEntryRequest)


DESCRIPTOR._options = None

_QUEUEAPI = _descriptor.ServiceDescriptor(
  name='QueueApi',
  full_name='yamcs.protobuf.commanding.QueueApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=750,
  serialized_end=1619,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListQueues',
    full_name='yamcs.protobuf.commanding.QueueApi.ListQueues',
    index=0,
    containing_service=None,
    input_type=_LISTQUEUESREQUEST,
    output_type=_LISTQUEUESRESPONSE,
    serialized_options=b'\212\222\003/\n-/api/processors/{instance}/{processor}/queues',
  ),
  _descriptor.MethodDescriptor(
    name='GetQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.GetQueue',
    index=1,
    containing_service=None,
    input_type=_GETQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=b'\212\222\0036\n4/api/processors/{instance}/{processor}/queues/{name}',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.UpdateQueue',
    index=2,
    containing_service=None,
    input_type=_EDITQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=b'\212\222\0039*4/api/processors/{instance}/{processor}/queues/{name}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ListQueueEntries',
    full_name='yamcs.protobuf.commanding.QueueApi.ListQueueEntries',
    index=3,
    containing_service=None,
    input_type=_LISTQUEUEENTRIESREQUEST,
    output_type=_LISTQUEUEENTRIESRESPONSE,
    serialized_options=b'\212\222\003>\n</api/processors/{instance}/{processor}/queues/{name}/entries',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateQueueEntry',
    full_name='yamcs.protobuf.commanding.QueueApi.UpdateQueueEntry',
    index=4,
    containing_service=None,
    input_type=_EDITQUEUEENTRYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003H*C/api/processors/{instance}/{processor}/queues/{name}/entries/{uuid}:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_QUEUEAPI)

DESCRIPTOR.services_by_name['QueueApi'] = _QUEUEAPI

# @@protoc_insertion_point(module_scope)
